@@ -4,12 +4,13 @@
  */
 
 #ifndef _EXT_LZMA_H
+#define _EXT_LZMA_H
 
 #include <LzmaDec.h>
 #include <Lzma2Dec.h>
 
-#include "contrib/minizip/ioapi.h"
-#include "contrib/minizip/unzip.h"
+#include "minizip/ioapi.h"
+#include "minizip/unzip.h"
 
 int hc_lzma1_decompress (const unsigned char *in, SizeT *in_len, unsigned char *out, SizeT *out_len, const char *props);
 int hc_lzma2_decompress (const unsigned char *in, SizeT *in_len, unsigned char *out, SizeT *out_len, const char *props);
